@@ -724,7 +724,8 @@ class Wrapper:
         # First, get methods from the defs files
         for func in self.parser.find_functions():
             funcname = func.c_name
-            if self.overrides.is_ignored(funcname):
+            if self.overrides.is_ignored(funcname) or \
+               self.overrides.is_type_ignored(func.ret):
                 continue
             try:
                 if self.overrides.is_overriden(funcname):
@@ -1341,6 +1342,8 @@ def write_enums(parser, overrides, prefix, fp=sys.stdout):
             continue
         if enum.typecode is None:
             for nick, value in enum.values:
+                if overrides.is_ignored(value):
+                    continue
                 fp.write(
                     '    PyModule_AddIntConstant(module, '
                     '(char *) pyg_constant_strip_prefix("%s", strip_prefix), %s);\n'
@@ -1394,11 +1397,15 @@ def write_extension_init(overrides, prefix, fp):
 
 def write_registers(parser, overrides, fp):
     for boxed in parser.boxes:
+        if overrides.is_type_ignored(boxed.c_name):
+            continue
         fp.write('    pyg_register_boxed(d, "' + boxed.name +
                  '", ' + boxed.typecode +
                  ', &Py' + boxed.c_name +
                  '_Type);\n')
     for pointer in parser.pointers:
+        if overrides.is_type_ignored(pointer.c_name):
+            continue
         fp.write('    pyg_register_pointer(d, "' + pointer.name +
                  '", ' + pointer.typecode +
                  ', &Py' + pointer.c_name + '_Type);\n')
